@@ -9,7 +9,7 @@ use Data::Dumper;
 use strict;
 use warnings;
 
-our $VERSION = "0.08";
+our $VERSION = "0.09";
 
 sub parsefile {
     my $self = shift;
@@ -159,16 +159,24 @@ sub _parse {
         } else {
             $fh = $opts->{generate_code};
         }
-        my $timestamp = localtime;
+        my $timestamp = ($opts->{'no_timestamp'}) ? '' : ' on '.localtime();
+        
+        my $package_str = ($opts->{'package_name'}) ?
+            "package $opts->{'package_name'};" : "";
+
+        my $source_str = ($source->{'file'}) ?
+            "file $source->{'file'}" : "inline text";
+
         print $fh <<"HEADER";
 ##
 ## This file was generated by Google::ProtocolBuffers ($VERSION)
-## on $timestamp
-##      
+## $timestamp from $source_str
+##
+$package_str
 use strict;
 use warnings;
 use Google::ProtocolBuffers;
-{       
+{
 HEADER
         foreach my $class_name (@created_classes) {
             print $fh $class_name->getPerlCode($opts);
@@ -571,10 +579,10 @@ Options are given as a hash reference, the recognizable options are:
 
 =over 4
 
-=item include_dir => $dir_name
+=item include_dir => [ $dir_name ]
 
 One proto file may include others, this option sets where to look for the
-included files.
+included files. Multiple dirs should be specificed as an ARRAYREF.
 
 =item generate_code => $filename or $file_handler
 
@@ -688,6 +696,11 @@ a fully qualified name 'package_test.Message' will result in Perl class
 'PackageTest::Message'. Option 'no_camel_case' turns name-mangling off.
 Names of fields, extensions and enum constants are not affected anyway.
 
+=item package_name (String)
+
+Package name to be put into generated Perl code; has no effect on Perl classes names and
+has no effect unless 'generate_code' is also set.
+
 =back
 
 =head2 MessageClass->encode($hashref)
@@ -962,6 +975,7 @@ L<JSON> and L<YAML>
 =head1 AUTHOR, ACKNOWLEDGEMENS, COPYRIGHT
 
 Author: Igor Gariev <gariev@hotmail.com>
+        the CSIRT Gadgets Foundation <csirtgadgets.org>
 
 Proto grammar is based on work by Alek Storm
 L<http://groups.google.com/group/protobuf/browse_thread/thread/1cccfc624cd612da>
